==> kadaster-gds2-1.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20130701/FilterDatumTijdType.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;


/**
 * <p>Java class for FilterDatumTijdType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FilterDatumTijdType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="DatumTijdVanaf" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
 *         &lt;element name="DatumTijdTot" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FilterDatumTijdType", propOrder = {
    "datumTijdVanaf",
    "datumTijdTot"
})
public class FilterDatumTijdType {

    @XmlElement(name = "DatumTijdVanaf")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdVanaf;
    @XmlElement(name = "DatumTijdTot")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdTot;

    /**
     * Gets the value of the datumTijdVanaf property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdVanaf() {
        return datumTijdVanaf;
    }

    /**
     * Sets the value of the datumTijdVanaf property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdVanaf(XMLGregorianCalendar value) {
        this.datumTijdVanaf = value;
    }

    /**
     * Gets the value of the datumTijdTot property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdTot() {
        return datumTijdTot;
    }

    /**
     * Sets the value of the datumTijdTot property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdTot(XMLGregorianCalendar value) {
        this.datumTijdTot = value;
    }

}

==> kadaster-gds2-2.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_proces/v20130701/FilterDatumTijdType.java <==

package nl.kadaster.schemas.gds2.afgifte_proces.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;


/**
 * &lt;p&gt;Java class for FilterDatumTijdType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="FilterDatumTijdType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="DatumTijdVanaf" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/&amp;gt;
 *         &amp;lt;element name="DatumTijdTot" type="{http://www.w3.org/2001/XMLSchema}dateTime" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FilterDatumTijdType", propOrder = {
    "datumTijdVanaf",
    "datumTijdTot"
})
public class FilterDatumTijdType {

    @XmlElement(name = "DatumTijdVanaf")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdVanaf;
    @XmlElement(name = "DatumTijdTot")
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar datumTijdTot;

    /**
     * Gets the value of the datumTijdVanaf property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdVanaf() {
        return datumTijdVanaf;
    }

    /**
     * Sets the value of the datumTijdVanaf property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdVanaf(XMLGregorianCalendar value) {
        this.datumTijdVanaf = value;
    }

    /**
     * Gets the value of the datumTijdTot property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getDatumTijdTot() {
        return datumTijdTot;
    }

    /**
     * Sets the value of the datumTijdTot property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setDatumTijdTot(XMLGregorianCalendar value) {
        this.datumTijdTot = value;
    }

}
